@@ -1,21 +1,26 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import datetime
 
 from django.db import models
 from django.core import exceptions
 from django.contrib.auth import get_user_model
 from django.conf import settings
+from django.utils import timezone
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.utils.translation import gettext_lazy as _
 from solo.models import SingletonModel
 from oscar.core.loading import get_model
 
 User = get_user_model()
+Source = get_model('payment', 'Source')
 UserAddress = get_model('address', 'UserAddress')
 Order = get_model('order', 'Order')
 ShippingAddress = get_model('order', 'ShippingAddress')
 
+ATM = 'atm'
+
 TEXT = "text"
 INTEGER = "integer"
 BOOLEAN = "boolean"
@@ -108,6 +113,52 @@ def ordererAddress2(self):
         return None
 
 Order.ordererAddress = ordererAddress2
+
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3296#ticket
+@property
+def useATM(self):
+    if Source.objects.filter(order=self, source_type__code=ATM).exists():
+        return True
+    else:
+        return False
+        
+@property
+def useATMPaymentSuccess(self):
+    if Source.objects.filter(order=self, source_type__code=ATM).exists():
+        source = Source.objects.get(order=self, source_type__code=ATM)
+        if not source.reference == '-':
+            return True
+        else:
+            return False
+    else:
+        return False
+        
+@property
+def useATMPaymentExpired(self):
+    expiredHours = settings.IUNO_SHOP_ATM_EXPIRED_HOURS
+    expiredHours = datetime.timedelta(hours=expiredHours)
+    now = timezone.localtime(timezone.now())
+    
+    if now - self.date_placed > expiredHours:
+        return True
+    return False
+        
+def setATMCode(self, code):
+    if Source.objects.filter(order=self, source_type__code=ATM).exists():
+        source = Source.objects.get(order=self, source_type__code=ATM)
+        source.reference = code
+        source.save()
+
+atmEnable = False
+if hasattr(settings, 'IUNO_SHOP_ATM_ENABLE'):
+    atmEnable = settings.IUNO_SHOP_ATM_ENABLE      
+if atmEnable:
+    Order.useATM = useATM
+    Order.useATMPaymentSuccess = useATMPaymentSuccess
+    Order.useATMPaymentExpired = useATMPaymentExpired
+    Order.setATMCode = setATMCode
+    Order.ATMBankCode = settings.IUNO_SHOP_ATM_PAYMENT_INFO['bank']
+    Order.ATMAccount = settings.IUNO_SHOP_ATM_PAYMENT_INFO['account']
     
 @property
 def isOrdererAddress(self):
@@ -165,25 +216,28 @@ class BonusRecord(models.Model):
 def hasReceiveBonus(self):
     return BonusRecord.objects.filter(order=self).exists()
     
-@property
-def canReceiveBonus(self):
+def calcReceiveBouns(total, shipping):
     config = BonusSettings.objects.get()
     
-    # receive
-    if self.shipping_excl_tax:
+    if shipping:
         consumption = (
-            int(self.total_excl_tax) - config.consumption - 
-            int(self.shipping_excl_tax))
+            int(total) - config.consumption - 
+            int(shipping))
     else:
         consumption = (
-            int(self.total_excl_tax) - config.consumption)
-    
+            int(total) - config.consumption)
+            
     receive = 0
     if consumption >= 0:
         # config.percent / 100 = X %
         receive = int(consumption * (config.percent / 100))
+        
     return receive
     
+@property
+def canReceiveBonus(self):
+    return calcReceiveBouns(self.total_excl_tax, self.shipping_excl_tax)
+    
 Order.hasReceiveBonus = hasReceiveBonus
 Order.canReceiveBonus = canReceiveBonus
     
@@ -211,7 +265,7 @@ class BonusSettings(SingletonModel):
     
     receiveStatus = models.CharField(
         choices=settings.OSCAR_ORDER_STATUS, 
-        default=settings.OSCAR_INITIAL_ORDER_STATUS,
+        default=settings.OSCAR_ORDER_COMPLETE_STATUS,
         max_length=50, verbose_name=_("Receive status"))
     
     includeRange = models.ForeignKey(
