@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11802 2019-12-17 16:04:02Z Lavender $
+# $Id: views.py 11817 2019-12-24 14:40:36Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-12-18 01:04:02 +0900 (週三, 18 十二月 2019) $
-# $Revision: 11802 $ 
+# $Date: 2019-12-24 23:40:36 +0900 (週二, 24 十二月 2019) $
+# $Revision: 11817 $ 
 
 import json
 import logging
@@ -58,7 +58,7 @@ from Iuno.shop import buildAPIForm
 from Iuno.shop.models import (
     ECPayTrade, AllPayTrade, SpgatewayTrade, CathaybkCreditTrade,
     ECPayLogisticTrade, OrderOrdererAddress, OrdererAddress, 
-    BonusSettings, BonusRecord, Bonus)
+    BonusSettings, BonusRecord, Bonus, calcReceiveBouns)
 from Iuno.shop.Util import createCheckValue
 
 _PaymentDetailsView = get_class('checkout.views', 'PaymentDetailsView')
@@ -91,6 +91,7 @@ ALLPAY = 'allpay'
 ECPAY = 'ecpay'
 ECPAY_LOGISTIC = 'ecpay_logistic'
 ECPAY_MAP = 'ecpay_map'
+ATM = 'atm'
 
 CATHAYBK_CREDIT = 'cathaybk-credit' # /cathaybk-credit/checkxml/
 CATHAYBK_CUP = 'cathaybk-cup' # /cathaybk-cup/checkxml/
@@ -130,6 +131,10 @@ def get_context_data(self, **kwargs):
     cathaybkEnable = False
     if hasattr(settings, 'IUNO_SHOP_CATHAYBK_ENABLE'):
         cathaybkEnable = settings.IUNO_SHOP_CATHAYBK_ENABLE
+        
+    atmEnable = False
+    if hasattr(settings, 'IUNO_SHOP_ATM_ENABLE'):
+        atmEnable = settings.IUNO_SHOP_ATM_ENABLE
     
     if ecpayEnable:
         kwargs['ecpay'] = buildAPIForm(submission, self.request, 'ecpay')
@@ -144,7 +149,10 @@ def get_context_data(self, **kwargs):
                                         submission, self.request, 'spgateway')
     if cathaybkEnable:
         kwargs['cathaybk'] = buildAPIForm(
-                                        submission, self.request, 'cathaybk')
+                                        submission, self.request, 'cathaybk')                                       
+    if atmEnable:
+        kwargs['atm'] = buildAPIForm(
+                                        submission, self.request, 'atm') 
 
     if self.request.session.get('logisticMap'):
         mapData = json.loads(self.request.session['logisticMap'])
@@ -271,24 +279,13 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
                 )
         
         # bonus   
-        config = BonusSettings.objects.get(id=1)
+        config = BonusSettings.objects.get()
         
         if user.is_authenticated:
             b, created = Bonus.objects.get_or_create(user=user)
                 
             # receive
-            if shipping_charge:
-                consumption = (
-                    int(total.excl_tax) - config.consumption - 
-                    int(shipping_charge.excl_tax))
-            else:
-                consumption = (
-                    int(total.excl_tax) - config.consumption)
-            
-            receive = 0
-            if consumption >= 0:
-                # config.percent / 100 = X %
-                receive = int(consumption * (config.percent / 100))
+            receive = calcReceiveBouns(total.excl_tax, shipping_charge.excl_tax)
                 
             # use
             use = 0
@@ -485,18 +482,7 @@ def handle_order_status_change(self, order, new_status, note_msg=None):
         b, created = Bonus.objects.get_or_create(user=user)
         
         # receive
-        if order.shipping_excl_tax:
-            consumption = (
-                int(order.total_excl_tax) - config.consumption - 
-                int(order.shipping_excl_tax))
-        else:
-            consumption = (
-                int(order.total_excl_tax) - config.consumption)
-        
-        receive = 0
-        if consumption >= 0:
-            # config.percent / 100 = X %
-            receive = int(consumption * (config.percent / 100))
+        receive = order.canReceiveBonus
             
         # use
         use = 0
@@ -1063,7 +1049,7 @@ class SuccessResponseView2(_PaymentDetailsView):
         
         if not self.apiName in [
             SPGATEWAY, ALLPAY, ECPAY, CATHAYBK_CREDIT, 
-            CATHAYBK_CUP, ECPAY_MAP, ECPAY_LOGISTIC]:
+            CATHAYBK_CUP, ECPAY_MAP, ECPAY_LOGISTIC, ATM]:
             raise ValueError("Not pay api name: %s" % apiName)
 
         try:
@@ -1357,7 +1343,10 @@ class SuccessResponseView2(_PaymentDetailsView):
                             "Please try again.")
                         messages.error(self.request, msg)
                         return redirect('checkout:payment-details')
-
+            elif self.apiName == ATM:
+                self.tradeNo = '-'
+                self.tradeAmt = int(request.POST.get('total'))
+                self.basketId = int(request.POST.get('basketId'))
 
             if self.request.session.get('logisticMap'):
                 submission = super(
@@ -1382,7 +1371,7 @@ class SuccessResponseView2(_PaymentDetailsView):
                     request, 'shop/payment/LogisticRedirect.html', ctx)
             
             # ECPAY_LOGISTIC 不需要 loadFrozenBasket
-            if not self.apiName == ECPAY_LOGISTIC:
+            if not self.apiName in [ECPAY_LOGISTIC, ]:
                 errorMsg = _(
                     "A problem occurred communicating with %(apiName)s "
                     "- please try again later"
@@ -1757,6 +1746,46 @@ class ECPayServerReplyView(generic.View):
         except Exception as e:
             logger.error(str(e))
             return HttpResponse("|ErrorMessage")
+            
+class ATMFillView(generic.View):
+
+    def getOrder(self, request, *args, **kwargs):
+        orderNumber = kwargs.get('orderNumber')
+        order = get_object_or_404(Order, number=orderNumber)
+        return order
+
+    def get(self, request, *args, **kwargs):
+        order = self.getOrder(request, *args, **kwargs)
+        
+        return render(
+            request, 
+            "shop/payment/FillAccount.html",
+            {
+                'order': order,
+            }
+        )
+        
+    def post(self, request, *args, **kwargs):
+        order = self.getOrder(request, *args, **kwargs)
+        code = request.POST.get('account', None)
+        
+        if code and len(code) == 5: 
+            # 帳號限制要5碼
+            order.setATMCode(code)
+        else:
+            messages.error(
+                request, 
+                _('Please fill in the last five number of your account')
+            )
+        
+        return render(
+            request, 
+            "shop/payment/FillAccount.html",
+            {
+                'order': order,
+            }
+        )
+        
 
 
 
